
;; ~/.emacs
;; Only GNU Emacs reads this file


;; File layout controlled by Emacs folding.el available at:
;; http://www.csd.uu.se/~andersl/emacs.shtml
;; http://tiny-tools.sourceforge.net/
;; Now it is also available at MELPA
;; I use a Debian package called emacs-goodies-el

;; To use folding under Vim put this to your ~/.vimrc
;; set foldmethod=marker

;; Yes, I am pervert: I use both Emacs and Vim.
;; And sometimes I even edit my .emacs with Vim.

;;{{{ Originally from Dotfile Generator

;; completion
(setq completion-auto-help t)

;; misc
(setq next-line-add-newlines nil)
(setq track-eol t)
(setq require-final-newline t)

;; tags configuration
(setq tags-file-name "TAGS")

;; preserve position of cursor
(setq scroll-preserve-screen-position t)

;; Yank at current point, not to place, where
;; mouse is.
(setq mouse-yank-at-point t)

;;}}}
;;{{{ Misc 1


(setq default-major-mode 'text-mode)
(add-hook 'text-mode-hook 'turn-on-auto-fill)

;;(add-hook 'mail-mode-hook 'turn-on-auto-fill)

;;(setq auto-mode-alist (cons '("Wishlist" . text-mode) auto-mode-alist))
;;(setq auto-mode-alist (cons '("README" . text-mode) auto-mode-alist))
;;(setq auto-mode-alist (cons '("cvs*" . text-mode) auto-mode-alist))

;;(add-to-list 'auto-mode-alist '("\\.cron\\(tab\\)?\\'" . crontab-mode))
;;(add-to-list 'auto-mode-alist '("cron\\(tab\\)?\\." . crontab-mode))

(setq auto-mode-alist (cons '("*tmp/mutt-*" . mail-mode) auto-mode-alist))
(add-to-list 'auto-mode-alist '("\\.*tmp/mutt-.*\\'" . mail-mode))
(add-to-list 'auto-mode-alist '("\\.muttrc\\'" . muttrc-mode))



;; No tabs in source code.
;; http://adamspiers.org/computing/why_no_tabs.html
;; http://www.jwz.org/doc/tabs-vs-spaces.html
;; http://www.emacswiki.org/emacs/TabsAreEvil
(setq c-basic-indent 8)
(setq tab-width 8)
(setq default-tab-width 8)
(setq indent-tabs-mode nil)
(setq-default indent-tabs-mode nil)



;; C-mode for sources of Linux kernel
;; (As Linus Torvalds recommends)
;; See also: http://jeremy.zawodny.com/emacs/.emacs

(defun linux-c-mode ()
  "C mode with adjusted defaults for use with the Linux kernel."
  (interactive)
  (c-mode)
  (c-set-style "K&R")
 ;(setq c-basic-offset 8)
 ;(setq c-indent-level 8)
 ;(setq c-brace-imaginary-offset 0)
 ;(setq c-brace-offset -8)
 ;(setq c-argdecl-indent 8)
 ;(setq c-label-offset -8)
 ;(setq c-continued-statement-offset 8)
  (setq indent-tabs-mode nil)
  (setq tab-width 8)
  )

;; Use it for all C-code
(setq auto-mode-alist (cons '("/.*\\.[ch]$" . linux-c-mode) auto-mode-alist))
(setq auto-mode-alist (cons '("\\.cc$" . cc-mode) auto-mode-alist))
(setq auto-mode-alist (cons '("\\.hh$" . cc-mode) auto-mode-alist))

;; One space after sentence, not two
(setq sentence-end "[.?!][]\"')}]*\\($\\|[ \t]\\)[ \t\n]*")
(setq sentence-end-double-space nil)

;; Mouse avoidance

;;(mouse-avoidance-mode 'none)  ;; turn it off
(mouse-avoidance-mode 'jump)  ;; jump away randomly when approached
;;(mouse-avoidance-mode 'banish) ;; jump to corner when typing
;;(mouse-avoidance-mode 'exile) ;; jump to corner when approached
;;(mouse-avoidance-mode 'animate) ;; fru-fru
;;(mouse-avoidance-mode 'cat-and-mouse) ;; same
;;(mouse-avoidance-mode 'proteus)  ;; same + change the cursor shape

(display-time)



;;}}}
;;{{{ Set backup-dir
(setq make-backup-files t)
(setq
 backup-by-copying t ; don't clobber symlinks
 backup-directory-alist '(("." . "~/.emacs-backup")) ; don't litter my fs tree
 delete-old-versions t
 kept-new-versions 6
 kept-old-versions 2
 version-control t ; use versioned backups
 )

;;}}}
;;{{{ Fonts, colors and window size

(load-theme 'juhtolv t)

(set-default-font "Monospace 9")

;; Somehow X-resources do not have effect for first window in my GNU Emacs.
(setq initial-frame-alist
      '(
        (top . 0) (left . 0)
        (width . 154) (height . 53)
        (cursor-type . box)
        (foreground-color . "LightSalmon1")
        (background-color . "MidnightBlue")
        (font . "Monospace 9")
        )
      )

(setq default-frame-alist
      '(
        (top . 0) (left . 0)
        (width . 154) (height . 53)
        (cursor-type . box)
        (foreground-color . "LightSalmon1")
        (background-color . "MidnightBlue")
        (font . "Monospace 9")
        )
      )

;;(show-paren-mode p)
(show-paren-mode nil)

;;; emoji-fontset font
;(emoji-fontset-enable "Symbola")

;;(add-to-list 'load-path "/path/to/emacs-emoji-cheat-sheet-plus")
;(require 'emoji-cheat-sheet-plus)

;;; Nice mode, but I do not want to keep it always on:
;;(crosshairs-mode)

;;; This makes folding-mode behave weirdly. On the other hand,
;;; crosshairs-mode is better.
;;(require 'fringe-current-line)
;;(global-fringe-current-line-mode 1)

;;; Do not work well with crosshairs-mode
;;(global-vi-tilde-fringe-mode)



;;}}}
;;{{{ Finlandization or Finnlandisierung

(set-language-environment "UTF-8")
(set-keyboard-coding-system 'utf-8)
(set-terminal-coding-system 'utf-8)

;; note: iso-8859-* are aliases, must use iso-latin-* names
(setq mm-coding-system-priorities
      '(us-ascii iso-latin-1 iso-latin-9 utf-8))

(setq x-select-request-type '(UTF8_STRING COMPOUND_TEXT TEXT STRING))

;;(set-input-method "japanese-anthy")

;;}}}
;;{{{ Misc 2

;; Scrollbars
(set-scroll-bar-mode 'right)

;; "This means that you can release the modifier key before pressing
;; down the key that you wish to be modified. Although this is
;; non-standard behavior, it is recommended because it reduces the
;; strain on your hand, thus reducing the incidence of the dreaded
;; Emacs-pinky syndrome."
(setq modifier-keys-are-sticky t)

;; Switch off toolbars
(tool-bar-mode -1)

;; Make minibuffer resizeable (FIXME: Do not work)
;;(resize-minibuffer-mode)

;;; http://www.emacswiki.org/emacs/AutoCompressionMode
(auto-compression-mode 1)

;;; Stuff from Xah Lee
;;; http://xahlee.org/emacs/emacs23_features.html

(global-visual-line-mode 0) ; 1 for on, 0 for off.

(global-linum-mode 0) ; do not show line numbers

;; for xml files, use nxml-mode instead of sgml-mode
(add-to-list 'auto-mode-alist '("\\.xml\\'" . nxml-mode))
(add-to-list 'auto-mode-alist '("\\.html\\'" . nxml-mode))
(add-to-list 'auto-mode-alist '("\\.xhtml\\'" . nxml-mode))


;;}}}
;;{{{ Cool elisp packages
(add-to-list 'load-path "~/.elisp/")

;;{{{ Abbrev-mode
;; http://www.emacswiki.org/cgi-bin/wiki/AbbrevMode
(setq abbrev-file-name  ;; tell emacs where to read abbrev
      "~/.emacs.d/abbrev_defs") ;; definitions from...

;; Save abbrevs when files are saved. you will be asked before the
;; abbreviations are saved.
(setq save-abbrevs t)


(quietly-read-abbrev-file) ;; reads the abbreviations file on startup

;; Run it in text-mode
;; FIXME: Add E-Mail and Usenet News modes
(add-hook 'text-mode-hook 
          (lambda () 
            (abbrev-mode 1)
            )
          )
;;}}}
;;{{{ boxes.el
;; http://boxes.thomasjensen.com/
;; http://boxes.thomasjensen.com/docs/install.shtml#emacs
;; http://boxes.thomasjensen.com/docs/boxes.el
;; Remember to update the design list when you add new designs to your config file.
(load "~/.elisp/boxes.el")
(autoload 'boxes-command-on-region "boxes" nil t)
(autoload 'boxes-remove "boxes" nil t)
(autoload 'boxes-create "boxes" nil t)
(global-set-key "\C-cq" 'boxes-create)
(global-set-key "\C-cr" 'boxes-remove)

;;}
;;{{{ folding.el
;; http://www.csd.uu.se/~andersl/emacs.shtml
;; http://tiny-tools.sourceforge.net/
;; Now part of XEmacs and emacs-goodies

;; It is available from MELPA, but I use a Debian package called
;; emacs-goodies-el

;; Two ways to load:

;; Load folding-mode automatically, when folding-mode is asked via M-x .
(autoload 'folding-mode "folding" "Folding mode" t)
(autoload 'turn-off-folding-mode "folding" "Folding mode" t)
(autoload 'turn-on-folding-mode "folding" "Folding mode" t)

;; every file you open will be searched for folding marks:
;;(load "folding" 'nomessage 'noerror)
;;(folding-mode-add-find-file-hook)
;;}}}
;;{{{ The Insidious Big Brother Database
;;(bbdb-initialize 'gnus 'message 'sc)
(bbdb-initialize 'gnus 'message)
;;}}}
;;;{{{ Packages

;;; To use it, type:

;;; M-x package-list-packages
;;; M-x list-packages

(require 'package)

(setq package-archives '(
                         ;;; Phased out?
                         ;;("ELPA" . "http://tromey.com/elpa/")
                         ("gnu" . "http://elpa.gnu.org/packages/")
                         ("marmalade" . "http://marmalade-repo.org/packages/")
                         ("melpa" . "https://melpa.org/packages/")
                         ("melpa-stable" . "https://stable.melpa.org/packages/")
                         ("popkit" . "http://elpa.popkit.org/packages/")
                         ("SC"  . "http://joseito.republika.pl/sunrise-commander/")
                         )
      )

(package-initialize)

;;}}}
;;{{{ Flyspell
;; http://www-sop.inria.fr/mimosa/Manuel.Serrano/flyspell/flyspell.html

;;(setq ispell-program-name "aspell")
;; You’d better have tmispell-wrapper installed:
(setq ispell-program-name "ispell")
(setq flyspell-sort-corrections nil)
(add-hook 'LaTeX-mode-hook 'flyspell-mode)
;;}}}
;;{{{ FVWM-mode
;(load "~/.elisp/fvwm-mode.el")
;; Load fvwm−mode on Emacs startup
;(require 'fvwm−mode)

;;(add-to-list 'auto-mode-alist '("\\.*fvwmrc.*\\'" . fvwm-mode))
;;}}}
;;{{{ LaTeX: AUCTeX, Ref-TeX and outline-minor-mode

(require 'tex-site)

;;; This hangs my emacs in startup and its daemon mode refuse connections.
;(require 'context)

(setq TeX-auto-save t)
(setq TeX-parse-self t)
(setq-default TeX-master nil)

;; Enable RefTeX:
(add-hook 'LaTeX-mode-hook 'turn-on-reftex)
;; Plug it in AUCTeX:
(setq reftex-plug-into-AUCTeX t)

;; Some speedups for RefTeX
(setq reftex-keep-temporary-buffers t)
(setq reftex-enable-partial-scans t)
(setq reftex-save-parse-info t)
(setq reftex-use-multiple-selection-buffers t)

;; BibTeX and RefTeX
(setq bib-cite-use-reftex-view-crossref t)

;; imenu for RefTeX
(setq reftex-load-hook (quote (imenu-add-menubar-index)))
(setq reftex-mode-hook (quote (imenu-add-menubar-index)))


;; Enable folding and/or outline -minormodes of AUCTeX
(add-hook 'LaTeX-mode-hook '(lambda ()
                              (TeX-fold-mode 1)))
(add-hook 'LaTeX-mode-hook
          (lambda ()
            (outline-minor-mode 1)
            )
          )
(add-hook 'outline-minor-mode-hook
          (lambda ()
            (require 'foldout)
            )
          )
(eval-after-load "outline" '(require 'foldout))
(eval-after-load "outline-minor-mode" '(require 'foldout))
(setq tex-dvi-view-command "xdvi")
(add-hook
 'bibtex-mode-hook
 (lambda ()
   (imenu-add-to-menubar "Imenu")))

;;}}}
;;{{{ muttrc-mode
(load "~/.elisp/muttrc-mode.el")
(add-to-list 'auto-mode-alist '("\\.*muttrc\\'" . muttrc-mode))
;;}}}
;;{{{ recentf.el
;; Part of GNU Emacs but not part of XEmacs
;; Works fine with XEmacs, though
;; http://perso.wanadoo.fr/david.ponce/more-elisp.html
;; http://www.messengers-of-messiah.org/~csebold/emacs/
(require 'recentf)
(recentf-mode 1)
;;}}}
;;{{{ Tramp
(setq tramp-default-method "scp")
;;}}}
;;{{{ type-break.el
;; Part of GNU Emacs
;; http://www.splode.com/~friedman/software/emacs-lisp/src/type-break.el
(type-break-mode)
(setq type-break-mode-line-message-mode t)
;;}}}
;;{{{ unicode-fonts

;;(require 'unicode-fonts)
;;(unicode-fonts-setup)

;;}}}
;;{{{ VIPER and vimpulse.el
;; http://www.cs.sunysb.edu/~kifer/emacs.html
;; Viper Is a Package for Emacs Rebels;
;; VI Plan for Emacs Rescue
;; venomous VI PERil.
;; Rest of my VIPER-configs are in a file ~/.viper

;(setq viper-mode t)                ; enable Viper at load time
;(require 'viper)                   ; load Viper
;(load "~/.elisp/vimpulse.el")
;(setq vimpulse-experimental nil)   ; don't load bleeding edge code (see 6. installation instruction)
;(require 'vimpulse)                 ; load Vimpulse
;;(setq woman-use-own-frame nil)     ; don't create new frame for manpages
;;(setq woman-use-topic-at-point t)  ; don't prompt upon K key (manpage display)

;;;; If you keep getting annoyed that deletion stops at the
;;;; beginning of the line, this line fixes that.
;(setq viper-ex-style-editing nil)

;;}}}
;;{{{ White-space mode
;;; http://xahlee.org/emacs/whitespace-mode.html

;;; I do not want to keep it always on
;;(global-whitespace-mode)

;;; make whitespace-mode use just basic coloring
(setq whitespace-style (quote
                        ( spaces tabs newline space-mark tab-mark newline-mark)
;;( tabs newline space-mark tab-mark newline-mark)
                        )
      )
;; make whitespace-mode use “¶” for newline and “▷” for tab.
;; together with the rest of its defaults
(setq whitespace-display-mappings
      '(
                                      ;;(space-mark 32 [183] [46]) ;; normal space : · U+00B7 MIDDLE DOT
        (space-mark 32 [9251] [46])   ;; normal space: ␣ U+2423 OPEN BOX
                                      ;;(space-mark 32 [32] [46]) ;; normal space:  U+0020 SPACE
        (space-mark 160 [164] [95])   ;; U+00A0 NO-BREAK SPACE: ¤ U+00A4 CURRENCY SIGN
                                      ;;(space-mark 160 [9251] [95]) ;; U+00A0 NO-BREAK SPACE: ␣ U+2423 OPEN BOX
        (space-mark 2208 [2212] [95]) ;; ???
        (space-mark 2336 [2340] [95]) ;; ???
        (space-mark 3616 [3620] [95]) ;; ???
        (space-mark 3872 [3876] [95]) ;; ???
        (newline-mark 10 [182 10])    ;; newline
        (tab-mark 9 [9655 9] [92 9])  ;; tab
        )
      )

;;}}}
;;}}}

(custom-set-variables
 ;; custom-set-variables was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(browse-url-browser-function (quote browse-url-firefox))
 '(calendar-date-style (quote iso))
 '(calendar-day-name-array
   ["Sunnuntai" "Maanantai" "Tiistai" "Keskiviikko" "Torstai" "Perjantai" "Lauantai"])
 '(calendar-month-name-array
   ["Tammikuu" "Helmikuu" "Maaliskuu" "Huhtikuu" "Toukokuu" "Kesäkuu" "Heinäkuu" "Elokuu" "Syyskuu" "Lokakuu" "Marraskuu" "Joulukuu"])
 '(calendar-time-display-form
   (quote
    (24-hours ":" minutes
              (if time-zone " (")
              time-zone
              (if time-zone ")"))))
 '(calendar-week-start-day 1)
 '(column-number-mode t)
 '(current-language-environment "UTF-8")
 '(custom-safe-themes
   (quote
    ("fb9e4a0b6941fa8c865634fd6c50802c7dfc5b5398593f442ac0645bb5dad6f6" "10ddba07072464e4ef5ba4f7cd40b0c171f3e3536ec5d89adb894adad1fc06ff" "563ff75fa5af8786765f2da7c7fea7b8e8664acbcb024396b7187a958729e293" "09669536b4a71f409e7e2fd56609cd7f0dff2850d4cbfb43916cc1843c463b80" "cedd3b4295ac0a41ef48376e16b4745c25fa8e7b4f706173083f16d5792bb379" "561ba4316ba42fe75bc07a907647caa55fc883749ee4f8f280a29516525fc9e8" "c987721d93f0858a2eec882e58c5c45b67d6492bfadae3e00c115ba2616b7fe0" "0022e0b80aaf697a4dc41322d5270aff5c4dae342c09a559abb91fd2bc64e755" "6ffef0161169e444b514a0f7f0cb7eac09d11c396cdc99bf85360a361c427886" default)))
 '(describe-char-unidata-list
   (quote
    (name old-name general-category canonical-combining-class bidi-class decomposition decimal-digit-value digit-value numeric-value mirrored iso-10646-comment uppercase lowercase titlecase)))
 '(display-time-24hr-format t)
 '(display-time-day-and-date t)
 '(display-time-display-time-background "Black")
 '(display-time-display-time-foreground "Green")
 '(display-time-interval 10)
 '(display-time-mail-balloon nil)
 '(display-time-mail-face (quote mode-line))
 '(display-time-mail-file (quote none))
 '(display-time-mail-function nil)
 '(display-time-mode t nil (time))
 '(flyspell-default-dictionary "finnish-large")
 '(gnus-article-display-hook
   (quote
    (gnus-picons-article-display-x-face gnus-group-display-picons gnus-article-display-picons gnus-article-highlight gnus-article-highlight-he aders gnus-article-highlight-citation gnus-article-highlight-signature gnus-article-remove-trailing-blank-lines gnus-article-strip-leading-blank-lines gnus-smiley-display gnu s-article-emphasize gnus-article-de-quoted-unreadable gnus-article-highlight gnus-article-remove-trailing-blank-lines gnus-article-strip-leading-blank-lines gnus-smiley-displ ay)) t)
 '(gnus-article-sort-functions (quote (gnus-article-sort-by-number)))
 '(gnus-carpal nil t)
 '(gnus-group-charset-alist
   (quote
    (("\\(^\\|:\\)hk\\>\\|\\(^\\|:\\)tw\\>\\|\\<big5\\>" cn-big5)
     ("\\(^\\|:\\)cn\\>\\|\\<chinese\\>" cn-gb-2312)
     ("\\(^\\|:\\)fj\\>\\|\\(^\\|: \\)japan\\>" iso-2022-jp-2)
     ("\\(^\\|:\\)tnn\\>\\|\\(^\\|:\\)pin\\>\\|\\(^\\|:\\)sci.lang.japan" iso-2022-7bit)
     ("\\(^\\|:\\)relcom\\>" koi8-r)
     ("\\(^\\|:\\)fido7\\>" koi8-r)
     ("\\(^\\|:\\)\\(cz\\|hun\\|pl\\|sk\\|hr\\)\\>" iso-8859-2)
     ("\\(^\\|:\\)israel\\>" iso-8859-1)
     ("\\(^\\|:\\)han\\>" euc-kr)
     ("\\(^\\|:\\)alt.chinese.text.big5\\>" chinese-bi g5)
     ("\\(^\\|:\\)soc.culture.vietnamese\\>" vietnamese-viqr)
     ("\\(^\\|:\\)\\(finet\\|sfnet\\)\\>" iso-8859-1)
     ("\\(^\\|:\\)\\(comp\\|rec\\|alt\\|sci\\|soc\\|news\\|gnu\\|bofh \\)\\>" iso-8859-1))))
 '(gnus-group-line-format "%m%M%S%p%P:[%6,7y:%6,7t]: %(%g%) : %D : %d :
")
 '(gnus-nntp-server "news.individual.net")
 '(gnus-novice-user nil)
 '(gnus-pick-display-summary t)
 '(gnus-picons-display-article-move-p t)
 '(gnus-picons-display-where (quote article))
 '(gnus-score-default-duration (quote p))
 '(gnus-score-default-fold nil)
 '(gnus-score-default-header (quote a))
 '(gnus-score-default-type (quote s))
 '(gnus-show-all-headers nil)
 '(gnus-subscribe-newsgroup-method (quote gnus-subscribe-zombies))
 '(gnus-summary-default-score 0)
 '(gnus-summary-expunge-below -100)
 '(gnus-summary-line-format "%U%R%z:%-6,6i:%(%B%[%4L: %-20,20n%]%) %s : %o
")
 '(gnus-summary-mark-below -100)
 '(gnus-summary-prepare-hook nil)
 '(gnus-summary-prepared-hook nil)
 '(gnus-thread-hide-killed t)
 '(gnus-thread-indent-level 2)
 '(gnus-thread-sort-functions
   (quote
    (gnus-thread-sort-by-total-score gnus-thread-sort-by-number gnus-thread-sort-by-date)))
 '(gnus-treat-display-x-face (quote head))
 '(gnus-treat-from-picon nil)
 '(gnus-treat-mail-picon nil)
 '(gnus-treat-newsgroups-picon nil)
 '(gnus-treat-wash-html nil)
 '(gnus-use-cache t)
 '(gnus-use-full-window nil)
 '(gnus-use-picons nil)
 '(gnus-use-toolbar (quote left-toolbar))
 '(gnus-use-trees nil)
 '(gnus-visual
   (quote
    (summary-highlight group-highlight article-highlight mouse-face summary-menu group-menu article-menu tree-highlight menu highlight browse-menu server-me nu page-marker tree-menu binary-menu pick-menu grouplens-menu)))
 '(gnus-window-min-height 10)
 '(gnus-window-min-width 10)
 '(gutter-buffers-tab-visible-p nil)
 '(highlight-headers-highlight-citation-too t)
 '(highline-face (quote highline-face))
 '(indicate-buffer-boundaries (quote left))
 '(indicate-empty-lines t)
 '(lookout-bbdb-mapping-table (quote lookout-bbdb-mapping-table-pocket-lookout))
 '(lookout-diary-mapping-table (quote lookout-diary-mapping-table-outlook-xp-english))
 '(lookout-unmarked-categories nil)
 '(mail-source-delete-incoming nil)
 '(mail-source-idle-time-delay 60)
 '(mail-user-agent (quote gnus-user-agent))
 '(message-generate-headers-first t)
 '(message-kill-buffer-on-exit t)
 '(message-sent-hook
   (quote
    (gnus-score-followup-article gnus-score-followup-thread)))
 '(mm-coding-system-priorities (quote (us-ascii iso-8859-1 iso-8859-15 utf-8)) t)
 '(recentf-max-menu-items 40)
 '(recentf-max-saved-items 50)
 '(resize-minibuffer-window-exactly t t)
 '(rmail-summary-scroll-between-messages t)
 '(rst-level-face-base-color "gray20")
 '(safe-local-variable-values
   (quote
    ((TeX-auto-parse-length . 999999)
     (TeX-auto-regexp-list . TeX-auto-full-regexp-list)
     (TeX-auto-untabify . t)
     (TeX-parse-self . t)
     (minor-mode . folding)
     (minor-mode . folding-mode))))
 '(save-place t nil (saveplace))
 '(scroll-bar-mode (quote right))
 '(scroll-preserve-screen-position t)
 '(sh-shell-file "/bin/zsh")
 '(show-trailing-whitespace t)
 '(size-indication-mode t)
 '(spell-command "aspell")
 '(suggest-key-bindings 5)
 '(tab-width 8)
 '(text-mode-hook
   (quote
    ((lambda nil
       (abbrev-mode 1))
     turn-on-auto-fill text-mode-hook-identify)))
 '(tool-bar-mode nil nil (tool-bar))
 '(tooltip-x-offset 30)
 '(tooltip-y-offset 30))
(custom-set-faces
 ;; custom-set-faces was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(default ((t (:inherit nil :stipple nil :background "MidnightBlue" :foreground "LightSalmon1" :inverse-video nil :box nil :strike-through nil :overline nil :underline nil :slant normal :weight normal :height 88 :width normal :family "Monospace"))))
 '(LightGreen ((t (:foreground "LightGreen"))))
 '(blue ((t (:foreground "LightBlue"))))
 '(col-highlight ((t (:background "Black"))))
 '(cursor ((t (:background "Gold" :foreground "red"))))
 '(custom-comment ((nil (:background "black" :foreground "FireBrick"))))
 '(custom-comment-face ((nil (:background "black" :foreground "FireBrick"))))
 '(custom-comment-tag ((nil (:background "black" :foreground "Hotpink"))))
 '(custom-comment-tag-face ((nil (:background "black" :foreground "Hotpink"))))
 '(custom-documentation ((t (:foreground "salmon"))))
 '(custom-documentation-face ((t (:foreground "salmon"))))
 '(custom-group-tag ((((class color) (background light)) (:foreground "Orange" :underline t))))
 '(custom-group-tag-face ((((class color) (background light)) (:foreground "Orange" :underline t))))
 '(custom-state ((((class color) (background light)) (:foreground "LightGreen"))))
 '(custom-state-face ((((class color) (background light)) (:foreground "LightGreen"))))
 '(custom-variable-tag ((((class color) (background light)) (:foreground "lightskyblue" :underline t))))
 '(custom-variable-tag-face ((((class color) (background light)) (:foreground "lightskyblue" :underline t))))
 '(cvs-filename-face ((((class color) (background light)) (:foreground "blue4" :background "LightSalmon"))))
 '(diff-file-header-face ((((class color) (background light)) (:foreground "LightSalmon" :background "grey40" :bold t))))
 '(diff-hunk-header-face ((((class color) (background light)) (:foreground "LightSalmon" :background "grey30"))))
 '(diff-index-face ((((class color) (background light)) (:foreground "LightSalmon" :background "grey30" :bold t))))
 '(dired-face-flagged ((((class color)) (:background "LightSlateGray"))))
 '(dired-face-marked ((((class color)) (:foreground "Gold" :background "PaleVioletRed"))))
 '(display-time-mail-balloon-enhance-face ((t (:foreground "Blue" :background "orange"))) t)
 '(font-lock-builtin-face ((nil (:background "FireBrick" :foreground "Turquoise"))))
 '(font-lock-comment-delimiter-face ((default (:inherit font-lock-comment-face)) (((class color) (min-colors 16)) (:background "Black" :foreground "Yellow" :weight bold))))
 '(font-lock-comment-face ((t (:background "Black" :foreground "firebrick1"))))
 '(font-lock-doc-string-face ((((class color) (background light)) (:foreground "green3"))))
 '(font-lock-function-name-face ((t (:foreground "green" :weight bold))))
 '(font-lock-keyword-face ((nil (:background "Turquoise" :foreground "FireBrick"))))
 '(font-lock-negation-char-face ((t (:background "Black" :foreground "White"))))
 '(font-lock-preprocessor-face ((nil (:foreground "Yellow"))))
 '(font-lock-string-face ((nil (:background "SteelBlue4" :foreground "Turquoise"))))
 '(font-lock-type-face ((nil (:background "Turquoise" :foreground "Black"))))
 '(font-lock-variable-name-face ((nil (:background "LightGreen" :foreground "Red"))))
 '(fringe ((((class color) (background dark)) (:background "NavyBlue" :foreground "turquoise1"))))
 '(gnus-cite-1 ((((class color) (background dark)) (:background "gray40" :foreground "gray100"))))
 '(gnus-cite-10 ((((class color) (background dark)) (:background "gray4" :foreground "gray64"))))
 '(gnus-cite-11 ((((class color) (background dark)) (:background "gray0" :foreground "gray60"))))
 '(gnus-cite-2 ((((class color) (background dark)) (:background "gray36" :foreground "gray96"))))
 '(gnus-cite-3 ((((class color) (background dark)) (:background "gray32" :foreground "gray92"))))
 '(gnus-cite-4 ((((class color) (background dark)) (:background "gray28" :foreground "gray88"))))
 '(gnus-cite-5 ((((class color) (background dark)) (:background "gray24" :foreground "gray84"))))
 '(gnus-cite-6 ((((class color) (background dark)) (:background "gray20" :foreground "gray80"))))
 '(gnus-cite-7 ((((class color) (background dark)) (:background "gray16" :foreground "gray76"))))
 '(gnus-cite-8 ((((class color) (background dark)) (:background "gray12" :foreground "gray72"))))
 '(gnus-cite-9 ((((class color) (background dark)) (:background "gray8" :foreground "gray68"))))
 '(gnus-cite-face-1 ((t (:background "gray40" :foreground "gray100"))))
 '(gnus-cite-face-10 ((t (:background "gray4" :foreground "gray64"))))
 '(gnus-cite-face-11 ((t (:background "gray0" :foreground "gray60"))))
 '(gnus-cite-face-2 ((t (:background "gray36" :foreground "gray96"))))
 '(gnus-cite-face-3 ((t (:background "gray32" :foreground "gray92"))))
 '(gnus-cite-face-4 ((t (:background "gray28" :foreground "gray88"))))
 '(gnus-cite-face-5 ((t (:background "gray24" :foreground "gray84"))))
 '(gnus-cite-face-6 ((t (:background "gray20" :foreground "gray80"))))
 '(gnus-cite-face-7 ((t (:background "gray16" :foreground "gray76"))))
 '(gnus-cite-face-8 ((t (:background "gray12" :foreground "gray72"))))
 '(gnus-cite-face-9 ((t (:background "gray8" :foreground "gray68"))))
 '(gnus-group-mail-low ((((class color) (background light)) (:foreground "DeepPink2" :bold t))))
 '(gnus-group-mail-low-empty ((((class color) (background light)) (:foreground "DeepPink2"))))
 '(gnus-group-mail-low-empty-face ((((class color) (background light)) (:foreground "DeepPink2"))))
 '(gnus-group-mail-low-face ((((class color) (background light)) (:foreground "DeepPink2" :bold t))))
 '(gnus-group-news-1 ((((class color) (background light)) (:foreground "limegreen" :bold t))))
 '(gnus-group-news-1-empty ((((class color) (background light)) (:foreground "limegreen"))))
 '(gnus-group-news-1-empty-face ((((class color) (background light)) (:foreground "limegreen"))))
 '(gnus-group-news-1-face ((((class color) (background light)) (:foreground "limegreen" :bold t))))
 '(gnus-group-news-2 ((((class color) (background light)) (:foreground "CadetBlue3" :bold t))))
 '(gnus-group-news-2-empty ((((class color) (background light)) (:foreground "CadetBlue3"))))
 '(gnus-group-news-2-empty-face ((((class color) (background light)) (:foreground "CadetBlue3"))))
 '(gnus-group-news-2-face ((((class color) (background light)) (:foreground "CadetBlue3" :bold t))))
 '(gnus-group-news-low ((((class color) (background light)) (:foreground "mediumaquamarine" :bold t))))
 '(gnus-group-news-low-empty ((((class color) (background light)) (:foreground "mediumaquamarine"))))
 '(gnus-group-news-low-empty-face ((((class color) (background light)) (:foreground "mediumaquamarine"))))
 '(gnus-group-news-low-face ((((class color) (background light)) (:foreground "mediumaquamarine" :bold t))))
 '(gnus-header-content ((((class color) (background light)) (:foreground "thistle1" :italic t))))
 '(gnus-header-content-face ((((class color) (background light)) (:foreground "thistle1" :italic t))))
 '(gnus-header-from ((t (:background "red" :foreground "white"))))
 '(gnus-header-from-face ((nil (:foreground "Gold"))))
 '(gnus-header-name ((nil (:weight bold))))
 '(gnus-header-name-face ((nil (:weight bold))))
 '(gnus-header-newsgroups ((nil (:foreground "Grey85"))))
 '(gnus-header-newsgroups-face ((nil (:foreground "Grey85"))))
 '(gnus-header-subject ((t (:background "red" :foreground "white"))))
 '(gnus-header-subject-face ((nil (:foreground "Yellow"))))
 '(gnus-signature ((((type x)) (:foreground "GoldenRod1" :italic nil))))
 '(gnus-signature-face ((((type x)) (:foreground "GoldenRod1" :italic nil))))
 '(gnus-summary-high-ancient ((((class color) (background light)) (:foreground "DodgerBlue" :bold t))))
 '(gnus-summary-high-ancient-face ((((class color) (background light)) (:foreground "DodgerBlue" :bold t))))
 '(gnus-summary-high-read ((((class color) (background light)) (:foreground "Green" :bold t))))
 '(gnus-summary-high-read-face ((((class color) (background light)) (:foreground "Green" :bold t))))
 '(gnus-summary-high-ticked ((((class color) (background light)) (:foreground "hotpink" :bold t))))
 '(gnus-summary-high-ticked-face ((((class color) (background light)) (:foreground "hotpink" :bold t))))
 '(gnus-summary-low-ancient ((((class color) (background light)) (:foreground "DodgerBlue" :italic t))))
 '(gnus-summary-low-ancient-face ((((class color) (background light)) (:foreground "DodgerBlue" :italic t))))
 '(gnus-summary-low-read ((((class color) (background light)) (:foreground "DarkGreen" :italic t))))
 '(gnus-summary-low-read-face ((((class color) (background light)) (:foreground "DarkGreen" :italic t))))
 '(gnus-summary-low-ticked ((((class color) (background light)) (:foreground "violetred" :italic t))))
 '(gnus-summary-low-ticked-face ((((class color) (background light)) (:foreground "violetred" :italic t))))
 '(gnus-summary-normal-ancient ((((class color) (background light)) (:foreground "DodgerBlue"))))
 '(gnus-summary-normal-ancient-face ((((class color) (background light)) (:foreground "DodgerBlue"))))
 '(gnus-summary-normal-read ((((class color) (background light)) (:foreground "Green"))))
 '(gnus-summary-normal-read-face ((((class color) (background light)) (:foreground "Green"))))
 '(gnus-summary-normal-ticked ((((class color) (background light)) (:foreground "deeppink"))))
 '(gnus-summary-normal-ticked-face ((((class color) (background light)) (:foreground "deeppink"))))
 '(gnus-summary-selected ((t (:bold t :underline t :inverse-video t))))
 '(gnus-summary-selected-face ((t (:bold t :underline t :inverse-video t))))
 '(highlight ((t (:foreground "DarkOrchid" :background "darkseagreen2"))))
 '(highlight-current-line-face ((t (:background "wheat" :foreground "black"))))
 '(highline-face ((t (:background "grey20"))))
 '(hl-line ((t (:background "Black"))))
 '(holiday ((t (:foreground "blue" :background "pink"))))
 '(holiday-face ((t (:foreground "blue" :background "pink"))))
 '(hyper-apropos-documentation ((((class color) (background light)) (:foreground "LightSalmon" :background "MidnightBlue"))))
 '(hyper-apropos-hyperlink ((((class color) (background light)) (:foreground "LightSalmon" :background "MidnightBlue" :bold t :underline t))))
 '(info-node ((t (:foreground "Green" :background "Blue" :bold t :italic t))))
 '(info-xref ((t (:foreground "Green" :background "Blue" :bold t))))
 '(isearch ((t (:foreground "Red" :background "paleturquoise"))))
 '(lazy-highlight ((((class color) (background dark)) (:background "paleturquoise4" :foreground "wheat"))))
 '(list-mode-item-selected ((t (:foreground "VioletRed" :background "gray68"))))
 '(makefile-space-face ((((class color)) (:foreground "MidnightBlue" :background "hotpink"))))
 '(message-header-cc ((((class color) (background light)) (:foreground "Yellow"))))
 '(message-header-cc-face ((((class color) (background light)) (:foreground "Yellow"))))
 '(message-header-name ((((class color) (background dark)) (:foreground "Green"))))
 '(message-header-name-face ((((class color) (background dark)) (:foreground "Green"))))
 '(message-header-newsgroups ((nil (:foreground "Orange"))))
 '(message-header-newsgroups-face ((nil (:foreground "Orange"))))
 '(message-header-other ((((class color) (background light)) (:foreground "dodgerblue"))))
 '(message-header-other-face ((((class color) (background light)) (:foreground "dodgerblue"))))
 '(message-header-subject ((((class color) (background light)) (:foreground "Yellow" :bold t))))
 '(message-header-subject-face ((((class color) (background light)) (:foreground "Yellow" :bold t))))
 '(message-header-to ((((class color) (background light)) (:foreground "Yellow" :bold t))))
 '(message-header-to-face ((((class color) (background light)) (:foreground "Yellow" :bold t))))
 '(message-header-xheader ((((class color) (background light)) (:foreground "dodgerblue"))))
 '(message-header-xheader-face ((((class color) (background light)) (:foreground "dodgerblue"))))
 '(message-separator ((((class color) (background light)) (:foreground "tomato"))))
 '(message-separator-face ((((class color) (background light)) (:foreground "tomato"))))
 '(mode-line ((t (:background "LightSalmon" :foreground "MidnightBlue" :box (:line-width -1 :style released-button)))))
 '(mode-line-buffer-id ((t (:foreground "Blue" :background "LightSalmon"))))
 '(modeline-mousable ((t (:foreground "MediumBlue" :background "LightSalmon"))))
 '(modeline-mousable-minor-mode ((t (:foreground "Magenta" :background "LightSalmon"))))
 '(mouse ((t (:background "red" :foreground "yellow"))))
 '(pointer ((t (:foreground "Gold"))) t)
 '(primary-selection ((t (:foreground "Gold" :background "gray40"))))
 '(right-margin ((t (:foreground "Gold"))) t)
 '(rpm-spec-tag-face ((((class color) (background light)) (:foreground "blue" :background "lightsalmon"))))
 '(scroll-bar ((t (:background "grey60"))))
 '(secondary-selection ((t (:foreground "deeppink" :background "paleturquoise"))))
 '(sh-quoted-exec ((((class color) (background dark)) (:background "Tomato" :foreground "Blue"))))
 '(speedbar-directory-face ((((class color) (background light)) (:foreground "blue4" :background "Salmon"))))
 '(speedbar-file-face ((((class color) (background light)) (:foreground "cyan"))))
 '(speedbar-highlight-face ((((class color) (background light)) (:foreground "MidnightBlue" :background "green"))))
 '(text-cursor ((t (:foreground "red" :background "Gold"))))
 '(tool-bar ((t (:foreground "Gold" :background "MediumBlue"))))
 '(vertical-divider ((t (:foreground "MidnightBlue" :background "LightSalmon"))))
 '(widget-documentation ((((class color) (background light)) (:foreground "Green"))))
 '(widget-field ((((class grayscale color) (background light)) (:foreground "Black" :background "gray85"))))
 '(widget-inactive ((((class grayscale color) (background light)) (:foreground "dim gray" :background "NavyBlue"))))
 '(widget-single-line-field ((((type tty)) (:background "white" :foreground "blue"))))
 '(xsl-other-element-face ((((background light)) (:foreground "Blue" :background "LightSalmon"))))
 '(zmacs-region ((t (:foreground "Pink" :background "gray35"))))
 )


(put 'upcase-region 'disabled nil)

;;; Local Variables: ***
;;; coding: utf-8 ***
;;; End: ***

;;; vim: set ft=lisp fenc=utf-8 fdm=marker :

