#! /bin/zsh

######################################################################
## Filename:      savedgnus2maildir.sh
## Version:       1.1
## Description:   Convert Usenet News articles saved by Gnus to Maildir
## Author:        Juhapekka Tolvanen <juhtolv (at) iki (dot) fi>
## Created at:    Thu Sep 30 15:44:02 2004
## Modified at:   Tue Oct 26 03:49:52 2004
## Modified by:   Juhapekka Tolvanen <juhtolv (at) iki (dot) fi>
######################################################################

# Copyright (C) 2004,2010 Juhapekka Tolvanen
# <juhtolv (at) iki (dot) fi>

# URL: http://iki.fi/juhtolv/

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.

# This software is needed before running this:
# http://batleth.sapienti-sat.org/projects/mb2md/

GNUSSAVEDIR="${HOME}/News"
GNUSMAILDIR="${HOME}/Maildir.news"

MYDATE="`date +%Y-%m-%d_%T`"
MYTMPDIR="${HOME}/.savedgnus2maildir.dir/${MYDATE}"

#########################################################
# NO LUSER-MODIFIABLE SETTINGS BELOW THIS LINE, I HOPE
#########################################################

export POSIXLY_CORRECT="true"


if type mbox2maildir
then
    export MAILDIRCONVERTER="mbox2maildir"
else
    echo "Install mbox2maildir and try again" >&2
    exit 1
fi

#if type mb1md
#   then
#   MAILDIRCONVERTER="mb2md"
#elif type mbox2maildir
#   then
#   MAILDIRCONVERTER="mbox2maildir"
#else
#   echo "Install either mb2md or mbox2maildir and try again" >&2
#   exit 1
#fi


makemaildir ()
{
    # Args:
    # 1 : Directory of Maildir-folders (whole path)
    # 2 : Name of new Maildir
    if test ! -d ${1}/${2}
    then
        mkdir -v ${1}/${2}
    fi
    for a in cur new tmp
    do
        if test ! -d ${1}/${2}/${a}
        then
            mkdir -v ${1}/${2}/${a}
        fi
    done
}

generalline ()
{
    n="0"
    eval `resize`
    while test $n -lt $COLUMNS
    do
        printf "%b$1"
        n=$(($n+1))
    done
    echo ""
}


mkdir -v ${GNUSMAILDIR} 2> /dev/null
mkdir -v ${HOME}/.savedgnus2maildir.dir 2> /dev/null

mkdir -v ${MYTMPDIR} 2> /dev/null

mkdir -v ${MYTMPDIR}/ok
mkdir -v ${MYTMPDIR}/errors

mkdir -v ${MYTMPDIR}/MBOX
mkdir -v ${MYTMPDIR}/Maildir
mkdir -v ${MYTMPDIR}/Maildir.errors

cd ${GNUSSAVEDIR} || exit 1

for f in *~*.SCORE*(.)
do
    e="0"
    generalline
    echo ${f}
    if test ! -d ${GNUSMAILDIR}/${f}
    then
        makemaildir ${GNUSMAILDIR} ${f}
    fi
    makemaildir ${MYTMPDIR}/Maildir ${f}
    cd ${MYTMPDIR}/MBOX

# NOTE! Gnus do not save News-articles in Babyl format anymore.
#    echo "b2m "'<'" ${GNUSSAVEDIR}/${f} "'>'" ${MYTMPDIR}/MBOX/${f}"
#    b2m < ${GNUSSAVEDIR}/${f} > ${MYTMPDIR}/MBOX/${f}

    cp ${GNUSSAVEDIR}/${f} ${MYTMPDIR}/MBOX/${f}
    echo cp ${GNUSSAVEDIR}/${f} ${MYTMPDIR}/MBOX/${f}

    e="$(( $e + $? ))"

    if test $e -eq 0
    then
        if test "$MAILDIRCONVERTER" = "mb2md"
        then
            unset POSIXLY_CORRECT 2> /dev/null
            echo mb2md -s ${MYTMPDIR}/MBOX/${f} -d ${MYTMPDIR}/Maildir/${f}
            mb2md -s ${MYTMPDIR}/MBOX/${f} -d ${MYTMPDIR}/Maildir/${f}
            e="$(( $e + $? ))"
            export POSIXLY_CORRECT="true"
        elif test "$MAILDIRCONVERTER" = "mbox2maildir"
        then
            export MAIL="${MYTMPDIR}/MBOX/${f}"
            export MAILDIR="${MYTMPDIR}/Maildir/${f}"
            echo mbox2maildir
            mbox2maildir
            e="$(( $e + $? ))"
        else
            echo "Install either mb2md or mbox2maildir and try again" >&2
            exit 1
        fi
    fi
    if test $e -eq 0
    then
        pushd ${MYTMPDIR}/Maildir/${f}
        addlinesplain
        popd
    fi
    if test $e -eq 0
    then
        for h in ${MYTMPDIR}/Maildir/${f}/new/* ${MYTMPDIR}/Maildir/${f}/cur/*
        do
            mv -v "$h" ${GNUSMAILDIR}/${f}/cur/
            e="$(( $e + $? ))"
        done
    fi
    if test $e -eq 0
    then
        mv -fv ${GNUSSAVEDIR}/${f} ${MYTMPDIR}/ok/
        rmdir ${MYTMPDIR}/Maildir/${f}/cur
        rmdir ${MYTMPDIR}/Maildir/${f}/new
        rmdir ${MYTMPDIR}/Maildir/${f}/tmp
        rmdir ${MYTMPDIR}/Maildir/${f}
    else
        mv -fv ${GNUSSAVEDIR}/${f} ${MYTMPDIR}/errors/
        mv ${MYTMPDIR}/Maildir/${f} ${MYTMPDIR}/Maildir.errors/
    fi

    cd ${GNUSSAVEDIR}
    generalline
done

rmdir -v ${MYTMPDIR}/MBOX
rmdir -v ${MYTMPDIR}/Maildir
rmdir -v ${MYTMPDIR}/Maildir.errors
rmdir -v ${MYTMPDIR}/ok
rmdir -v ${MYTMPDIR}/errors

echo "MYTMPDIR = ${MYTMPDIR}"

